@@ -15,7 +15,7 @@ from deepdriver.sdk.config import Config
 from deepdriver.sdk.data_types.experiment import set_experiment, Experiment, get_experiment
 from deepdriver.sdk.data_types.run import set_run, Run, get_run
 from deepdriver.sdk.interface import interface
-
+from importlib.machinery import SourceFileLoader
 
 @util.login_required
 def init(exp_name: str = "", team_name: str = "", run_name: str = "", config: Dict = None) -> Run:
@@ -163,24 +163,30 @@ def prepare_code(code: dict = None) -> Tuple[bool, str, Callable]:
     else:
         path = arti.download()
         # finding code file in entry_list
-        file_entry_list = next((entry.local_path for entry in arti.entry_list if entry.path.endswith(code['file'])),
+        file_path = next((entry.local_path for entry in arti.entry_list if entry.path.endswith(code['file'])),
                                None)
-        if not file_entry_list:
+        if not file_path:
             raise Exception(f'cannot find file({code["file"]}) in artifcat')
 
-        # dynamically function load from file
-        with open(file_entry_list, "r") as file:
-            file_content = file.read()
-        node = ast.parse(file_content)
 
-        looking_for_body = next((body for body in node.body if body.name == code['fun']), None)
-        if not looking_for_body:
-            raise Exception(f'cannot find function({code["func"]}) in file_entry_list')
-        func_name = looking_for_body.name
-        func_source = ast.get_source_segment(file_content, looking_for_body)
-        exec(func_source)
+        loaded_module = SourceFileLoader(__name__, file_path).load_module()   # dynamically load module(with current module name)
+        if code['fun'] not in dir(loaded_module):
+            raise Exception(f'cannot find function({code["func"]}) in file([code["file"]])')
 
-        return True, path, eval(func_name)
+
+        # # dynamically function load from file
+        # with open(file_path, "r") as file:
+        #     file_content = file.read()
+        # node = ast.parse(file_content)
+        #
+        # looking_for_body = next((body for body in node.body if isinstance(body, ast.FunctionDef) and body.name == code['fun']), None)
+        # if not looking_for_body:
+        #     raise Exception(f'cannot find function({code["func"]}) in file_entry_list')
+        # func_name = looking_for_body.name
+        # func_source = ast.get_source_segment(file_content, looking_for_body)
+        # exec(func_source)
+
+        return True, path, eval(code['fun'])
 
 
 @util.login_required
